<?php

namespace FiloBlu\DisableShop\Observer;

use Magento\Framework\Event\Observer as EventObserver;
use Magento\Framework\Event\ObserverInterface;

class CatalogProductCollectionLoadAfter implements ObserverInterface {

    protected $_helper;

    public function __construct(
    \FiloBlu\DisableShop\Helper\Data $helper
    ) {
        $this->_helper = $helper;
    }

    public function execute(EventObserver $observer) {

        $this->_helper->log("### Catalog Product Collection Load After ###");
        
        $collection = $observer->getEvent()->getCollection();

        $_canDisableShop = $this->_helper->canDisableShop();
        $_canHidePrice = $this->_helper->canHidePrice();

        $this->_helper->log("- Can disable shop -> " . ($_canDisableShop ? "true" : "false"));
        $this->_helper->log("- Can hide price -> " . ($_canHidePrice ? "true" : "false"));
        
        $_categoriesDisableShop = explode(",",$this->_helper->getCategoriesDisabledShop());
        
        $_categoriesHidePrice = explode(",",$this->_helper->getCategoriesHidePrice());
        
        $this->_helper->log("- Categories disable shop:" . implode(',', $_categoriesDisableShop));
        
        $this->_helper->log("- Categories hide price shop:" . implode(',', $_categoriesHidePrice));
        
        foreach ($collection as $product) {

            $_canDisableShopSingleProduct = ($_canDisableShop ? true : $product->getDisableShop());
            
            if (!$_canDisableShopSingleProduct) {
                $_canDisableShopSingleProduct = (count(array_intersect($_categoriesDisableShop,$product->getCategoryIds())) ? true : false);
            }

            if ($_canDisableShopSingleProduct) {
                $product->setDisableAddToCart(true);
                //$product->setIsSalable(false); ????
                $this->_helper->log("- Can disable shop for product -> " . $product->getSku());
            }

            $_canHidePriceSingleProduct = ($_canHidePrice ? true : $product->getHidePrice());

            if (!$_canHidePriceSingleProduct) {
                $_canHidePriceSingleProduct = (count(array_intersect($_categoriesHidePrice,$product->getCategoryIds())) ? true : false);
            }
            
            if ($_canHidePriceSingleProduct) {
                $product->setCanShowPrice(false);
                $this->_helper->log("- Can hide price for product -> " . $product->getSku());
            }
        }
    }

}
